==> usd-24.03-7-x86_64.pkg.tar.zst: usr/include/pxr/imaging/hd/imageShader.h <==
//
// Copyright 2023 Pixar
//
// Licensed under the Apache License, Version 2.0 (the "Apache License")
// with the following modification; you may not use this file except in
// compliance with the Apache License and the following modification to it:
// Section 6. Trademarks. is deleted and replaced with:
//
// 6. Trademarks. This License does not grant permission to use the trade
//    names, trademarks, service marks, or product names of the Licensor
//    and its affiliates, except as required to comply with Section 4(c) of
//    the License and to reproduce the content of the NOTICE file.
//
// You may obtain a copy of the Apache License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the Apache License with the above modification is
// distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
// KIND, either express or implied. See the Apache License for the specific
// language governing permissions and limitations under the Apache License.
//
#ifndef PXR_IMAGING_HD_IMAGE_SHADER_H
#define PXR_IMAGING_HD_IMAGE_SHADER_H

#include "pxr/pxr.h"
#include "pxr/imaging/hd/api.h"
#include "pxr/imaging/hd/version.h"
#include "pxr/imaging/hd/sprim.h"

#include "pxr/base/tf/staticTokens.h"
#include "pxr/base/vt/dictionary.h"

#include <vector>

PXR_NAMESPACE_OPEN_SCOPE

#define HD_IMAGE_SHADER_TOKENS                              \
    (enabled)                                               \
    (priority)                                              \
    (filePath)                                              \
    (constants)

TF_DECLARE_PUBLIC_TOKENS(HdImageShaderTokens, HD_API, HD_IMAGE_SHADER_TOKENS);

class HdSceneDelegate;

/// \class HdImageShader
///
/// An image shader.
///
class HdImageShader : public HdSprim
{
public:
    HD_API
    HdImageShader(SdfPath const & id);
    HD_API
    ~HdImageShader() override;

    // Change tracking for HdImageShader
    enum DirtyBits : HdDirtyBits {
        Clean                 = 0,
        DirtyEnabled          = 1 << 0,
        DirtyPriority         = 1 << 1,
        DirtyFilePath         = 1 << 2,
        DirtyConstants        = 1 << 3,

        AllDirty              = (DirtyEnabled
                                 |DirtyPriority
                                 |DirtyFilePath
                                 |DirtyConstants)
    };

    // ---------------------------------------------------------------------- //
    /// Sprim API
    // ---------------------------------------------------------------------- //
 
    /// Synchronizes state from the delegate to this object.
    HD_API
    void Sync(
        HdSceneDelegate* sceneDelegate,
        HdRenderParam* renderParam,
        HdDirtyBits* dirtyBits) override;

    /// Returns the minimal set of dirty bits to place in the
    /// change tracker for use in the first sync of this prim.
    /// Typically this would be all dirty bits.
    HD_API
    HdDirtyBits GetInitialDirtyBitsMask() const override;

    // ---------------------------------------------------------------------- //
    /// Image shader parameters accessor API
    // ---------------------------------------------------------------------- //
    HD_API
    bool GetEnabled() const;

    HD_API
    int GetPriority() const;

    HD_API
    const std::string& GetFilePath() const;

    HD_API
    const VtDictionary& GetConstants() const;

private:
    bool _enabled;
    int _priority;
    std::string _filePath;
    VtDictionary _constants;
};

PXR_NAMESPACE_CLOSE_SCOPE

#endif  // PXR_IMAGING_HD_IMAGE_SHADER_H

==> usd-25.11-4-x86_64.pkg.tar.zst: usr/include/pxr/imaging/hd/imageShader.h <==
//
// Copyright 2023 Pixar
//
// Licensed under the terms set forth in the LICENSE.txt file available at
// https://openusd.org/license.
//
#ifndef PXR_IMAGING_HD_IMAGE_SHADER_H
#define PXR_IMAGING_HD_IMAGE_SHADER_H

#include "pxr/pxr.h"
#include "pxr/imaging/hd/api.h"
#include "pxr/imaging/hd/material.h"
#include "pxr/imaging/hd/sprim.h"
#include "pxr/imaging/hd/version.h"

#include "pxr/base/tf/staticTokens.h"
#include "pxr/base/vt/dictionary.h"

PXR_NAMESPACE_OPEN_SCOPE

#define HD_IMAGE_SHADER_TOKENS                              \
    (enabled)                                               \
    (priority)                                              \
    (filePath)                                              \
    (constants)                                             \
    (materialNetwork)

TF_DECLARE_PUBLIC_TOKENS(HdImageShaderTokens, HD_API, HD_IMAGE_SHADER_TOKENS);

class HdSceneDelegate;

using HdMaterialNetworkInterfaceUniquePtr =
    std::unique_ptr<class HdMaterialNetworkInterface>;

/// \class HdImageShader
///
/// An image shader.
///
class HdImageShader : public HdSprim
{
public:
    HD_API
    HdImageShader(SdfPath const & id);
    HD_API
    ~HdImageShader() override;

    // Change tracking for HdImageShader
    enum DirtyBits : HdDirtyBits {
        Clean                 = 0,
        DirtyEnabled          = 1 << 0,
        DirtyPriority         = 1 << 1,
        DirtyFilePath         = 1 << 2,
        DirtyConstants        = 1 << 3,
        DirtyMaterialNetwork  = 1 << 4,

        AllDirty              = (DirtyEnabled
                                 |DirtyPriority
                                 |DirtyFilePath
                                 |DirtyConstants
                                 |DirtyMaterialNetwork)
    };

    // ---------------------------------------------------------------------- //
    /// Sprim API
    // ---------------------------------------------------------------------- //
 
    /// Synchronizes state from the delegate to this object.
    HD_API
    void Sync(
        HdSceneDelegate* sceneDelegate,
        HdRenderParam* renderParam,
        HdDirtyBits* dirtyBits) override;

    /// Returns the minimal set of dirty bits to place in the
    /// change tracker for use in the first sync of this prim.
    /// Typically this would be all dirty bits.
    HD_API
    HdDirtyBits GetInitialDirtyBitsMask() const override;

    // ---------------------------------------------------------------------- //
    /// Image shader parameters accessor API
    // ---------------------------------------------------------------------- //
    HD_API
    bool GetEnabled() const;

    HD_API
    int GetPriority() const;

    HD_API
    const std::string& GetFilePath() const;

    HD_API
    const VtDictionary& GetConstants() const;

    HD_API
    const HdMaterialNetworkInterface* GetMaterialNetwork() const;

private:
    bool _enabled;
    int _priority;
    std::string _filePath;
    VtDictionary _constants;
    HdMaterialNetwork2 _materialNetwork;
    HdMaterialNetworkInterfaceUniquePtr _materialNetworkInterface;
};

PXR_NAMESPACE_CLOSE_SCOPE

#endif  // PXR_IMAGING_HD_IMAGE_SHADER_H
